==> dielectric_0.2.tar.gz: dielectric/inst/rawdata/AuAg.r <==

AuJC_raw <- data.frame(wavelength = c(1.93849485018727, 1.61121649885695, 1.39397382485376, 1.21631049423515, 
1.08827781063145, 0.984632304857024, 0.89254439145313, 0.821613711337649, 
0.756485795195031, 0.704907218249915, 0.659913140489282, 0.617232191104403, 
0.582458546535141, 0.548954293858341, 0.521275926100777, 0.49625468164794, 
0.471724982555076, 0.451140619679945, 0.430776633374948, 0.41354556803995, 
0.397639969269183, 0.381734370498415, 0.368141455228442, 0.354467629748529, 
0.342717321580069, 0.331721043882313, 0.320577959720891, 0.310936517323271, 
0.301125413621323, 0.292602996254682, 0.284549702779782, 0.276311069959878, 
0.269118590915369, 0.261737701291108, 0.255275041999969, 0.249123836168645, 
0.242786047772965, 0.237215430998059, 0.231462071664151, 0.226393559145958, 
0.22154226859283, 0.216516004209398, 0.212074650276897, 0.207464331792617, 
0.203383066249156, 0.199459277189687, 0.195375858916512, 0.191752195381739, 
0.187975258199977), epsilon = c(-189.042+25.3552i, -125.3505+12.5552i, -90.426461+8.18634i, 
-66.218525+5.7015i, -51.0496+3.861i, -40.2741+2.794i, -32.040669+1.92542i, 
-25.811289+1.62656i, -20.610164+1.27176i, -16.817709+1.06678i, 
-13.648209+1.03516i, -10.661884+1.37424i, -8.112669+1.66054i, 
-5.842125+2.1113i, -3.946161+2.58044i, -2.278289+3.81264i, -1.702701+4.84438i, 
-1.758996+5.28264i, -1.692204+5.6492i, -1.702164+5.71736i, -1.649404+5.73888i, 
-1.604889+5.64436i, -1.400625+5.6092i, -1.231956+5.598i, -1.310241+5.53816i, 
-1.355289+5.57368i, -1.230804+5.84584i, -1.242549+5.79258i, -1.227421+5.78034i, 
-1.306784+5.59644i, -1.332261+5.49486i, -1.366509+5.28242i, -1.346409+4.97628i, 
-1.236501+4.7223i, -1.080444+4.49008i, -0.891261+4.33846i, -0.744529+4.16328i, 
-0.616896+4.05504i, -0.551009+3.8922i, -0.4155+3.8252i, -0.346329+3.7102i, 
-0.233769+3.6062i, -0.1325+3.51i, -0.010416+3.3904i, 0.138171+3.39682i, 
0.203899+3.32766i, 0.292524+3.28568i, 0.295191+3.17592i, 0.227056+3.04128i
))

comment(AuJC_raw) <- c(source = "Gold in the visible, Johnson and Christy", 
                                units = "microns")

AuJC <- with(AuJC_raw, new("dielectric", wavelength=wavelength, epsilon=epsilon, span=range(wavelength), comment=as.list(comment(AuJC_raw))))

AgPalik_raw <- data.frame(wavelength=c(0.000124, 0.000155, 0.0002066, 0.000248, 0.0002755, 0.0003099, 
0.0003444, 0.0003542, 0.0004133, 0.0004959, 0.0006199, 0.0008265, 
0.00124, 0.00155, 0.001675, 0.002066, 0.00248, 0.003099, 0.003351, 
0.003542, 0.004133, 0.004428, 0.004768, 0.005166, 0.005635, 0.006199, 
0.006888, 0.007293, 0.007749, 0.008265, 0.008856, 0.009537, 0.01033, 
0.01127, 0.01181, 0.0124, 0.01305, 0.01378, 0.01459, 0.0155, 
0.01589, 0.01631, 0.01675, 0.01722, 0.01771, 0.01823, 0.01878, 
0.01937, 0.02, 0.02066, 0.02138, 0.02214, 0.02296, 0.02339, 0.02384, 
0.02431, 0.0248, 0.0253, 0.02583, 0.02638, 0.02695, 0.02818, 
0.02952, 0.03099, 0.03179, 0.03263, 0.03351, 0.03444, 0.03542, 
0.03646, 0.03757, 0.03874, 0.03999, 0.04132, 0.04275, 0.0435, 
0.04428, 0.04508, 0.04592, 0.04592, 0.04679, 0.04769, 0.04862, 
0.05061, 0.05276, 0.05391, 0.0551, 0.05636, 0.05767, 0.05904, 
0.06048, 0.06199, 0.06526, 0.06888, 0.07293, 0.07749, 0.07999, 
0.08266, 0.08551, 0.08856, 0.09184, 0.09537, 0.09919, 0.1025, 
0.1051, 0.1078, 0.1107, 0.1137, 0.117, 0.1204, 0.124, 0.1278, 
0.1348, 0.1378, 0.1409, 0.1442, 0.1476, 0.1512, 0.155, 0.159, 
0.1631, 0.1675, 0.1722, 0.1771, 0.1823, 0.1879, 0.1937, 0.1968, 
0.2, 0.2033, 0.2066, 0.2138, 0.2214, 0.2296, 0.2384, 0.248, 0.253, 
0.2583, 0.2638, 0.2695, 0.2755, 0.2818, 0.2883, 0.2952, 0.2988, 
0.3024, 0.3061, 0.31, 0.3115, 0.3139, 0.3155, 0.3179, 0.3195, 
0.322, 0.3237, 0.3263, 0.3306, 0.3324, 0.3351, 0.3397, 0.3444, 
0.3542, 0.3647, 0.3757, 0.3875, 0.4, 0.4133, 0.4275, 0.4428, 
0.4592, 0.4769, 0.4959, 0.5166, 0.5391, 0.5636, 0.5904, 0.6199, 
0.6526, 0.6888, 0.7293, 0.7749, 0.8266, 0.8856, 0.9537, 1.033, 
1.127, 1.24, 1.265, 1.291, 1.305, 1.319, 1.348, 1.378, 1.378, 
1.409, 1.442, 1.459, 1.476, 1.512, 1.55, 1.55, 1.59, 1.631, 1.653, 
1.675, 1.722, 1.771, 1.771, 1.823, 1.879, 1.907, 1.937, 2, 2.066, 
2.066, 2.138, 2.214, 2.296, 2.384, 2.48, 2.583, 2.695, 2.818, 
2.952, 3.1, 3.263, 3.444, 3.647, 3.875, 4.133, 4.428, 4.769, 
5.166, 5.636, 6.199, 6.526, 6.888, 7.293, 7.749, 8.266, 8.856, 
9.537, 9.919), 
epsilon=c(0.998000999998336+0.00000257742i, 0.999999999991473+0.00000584i, 
1.00400399993011+0.00001675344i, 1.00200099976896+0.0000304304i, 
1.00200099951159+0.0000442442i, 1.00600899872551+0.0000716142i, 
1.00600899895024+0.0000649944i, 1.00600899970416+0.0000345032i, 
1.00200099979551+0.0000286286i, 1.002000999424+0.000048048i, 
1.00200099777216+0.0000944944i, 0.998000985359+0.000241758i, 
0.996003726471+0.001043908i, 0.9940078336+0.00215352i, 0.9960019836+0.00283432i, 
0.9940017639+0.00536386i, 0.9939881151+0.00911258i, 0.9959262076+0.01760472i, 
1.0139812671+0.01657522i, 1.0019981776+0.00336336i, 0.9920106176+0.00462144i, 
0.98802871+0.0053676i, 0.9840543279+0.00617024i, 0.97810875+0.006923i, 
0.9741570975+0.0068103i, 0.9643097871+0.00740428i, 0.9564654239+0.00843036i, 
0.9467094636+0.00860132i, 0.9370048156+0.00847968i, 0.9273524351+0.00783882i, 
0.9120124684+0.0067614i, 0.8892356044+0.00690276i, 0.8574373116+0.01151944i, 
0.81330816+0.0310288i, 0.79141879+0.046458i, 0.76591676+0.0669264i, 
0.73812875+0.097293i, 0.71401124+0.1399152i, 0.703395+0.187812i, 
0.699783+0.235744i, 0.702+0.253598i, 0.702645+0.269548i, 0.700053+0.283196i, 
0.69144+0.308062i, 0.699072+0.338446i, 0.715377+0.362336i, 0.735168+0.372626i, 
0.739125+0.3717i, 0.73164+0.371782i, 0.713288+0.385866i, 0.697255+0.411432i, 
0.69156+0.451178i, 0.708149+0.48498i, 0.716475+0.4895i, 0.714145+0.490728i, 
0.706035+0.497932i, 0.697356+0.51272i, 0.693225+0.531i, 0.693063+0.548784i, 
0.69696+0.566162i, 0.698487+0.578816i, 0.696645+0.600532i, 0.682808+0.626106i, 
0.667392+0.659456i, 0.658141+0.67662i, 0.64512+0.692192i, 0.623225+0.708i, 
0.592652+0.732336i, 0.542109+0.78542i, 0.53352+0.859662i, 0.544005+0.924172i, 
0.569457+0.972576i, 0.583468+0.995376i, 0.57408+1.007342i, 0.534312+1.023766i, 
0.502737+1.042184i, 0.465504+1.06436i, 0.344745+1.048432i, 0.362496+1.1518i, 
0.618723+0.703836i, 0.607755+0.746012i, 0.589633+0.787656i, 0.574857+0.833976i, 
0.548352+0.945864i, 0.548193+1.101424i, 0.583404+1.20344i, 0.669465+1.284192i, 
0.7774+1.32225i, 0.87776+1.289472i, 0.91516+1.244298i, 0.919624+1.21329i, 
0.9053+1.203408i, 0.881991+1.23848i, 0.860552+1.305786i, 0.853416+1.42367i, 
0.904913+1.577784i, 0.967323+1.661164i, 1.0648+1.722798i, 1.17992+1.739598i, 
1.280528+1.716096i, 1.3533+1.660432i, 1.384075+1.594332i, 1.383481+1.54644i, 
1.373303+1.519896i, 1.366332+1.507424i, 1.361671+1.4898i, 1.351493+1.463676i, 
1.3248+1.4336i, 1.286625+1.4168i, 1.249408+1.412256i, 1.217457+1.409776i, 
1.190085+1.391228i, 1.094624+1.3002i, 1.015497+1.268496i, 0.919575+1.252112i, 
0.813768+1.246826i, 0.692924+1.25904i, 0.55964+1.296858i, 0.427008+1.358344i, 
0.2907+1.4476i, 0.182001+1.55584i, 0.080432+1.669824i, -0.017037+1.791684i, 
-0.111891+1.92506i, -0.205939+2.07366i, -0.286875+2.2487i, -0.335616+2.42608i, 
-0.365796+2.53616i, -0.388416+2.65856i, -0.381996+2.76696i, -0.347275+2.8575i, 
-0.288171+3.02634i, -0.230736+3.1408i, -0.183456+3.24356i, -0.168675+3.3649i, 
-0.137696+3.5046i, -0.0801+3.564i, -0.018851+3.6261i, 0.059884+3.7044i, 
0.202316+3.73464i, 0.360381+3.77542i, 0.590976+3.71952i, 0.839904+3.57476i, 
1.140961+3.28104i, 1.33242+3.019648i, 1.460092+2.638944i, 1.463868+2.193824i, 
1.33172+1.711962i, 1.20912+1.460312i, 1.028601+1.24092i, 0.82574+1.073232i, 
0.614608+0.939456i, 0.387549+0.85738i, 0.182039+0.80004i, 0.008575+0.750288i, 
-0.162893+0.697476i, -0.523328+0.603246i, -0.710563+0.579084i, 
-0.88576+0.579768i, -1.187319+0.58016i, -1.480956+0.59024i, -2.029919+0.60192i, 
-2.557504+0.59892i, -2.7489+0.668i, -3.239236+0.69504i, -3.772571+0.6747i, 
-4.422171+0.73006i, -5.082+0.7232i, -5.735351+0.7536i, -6.532864+0.73728i, 
-7.380976+0.71808i, -8.2775+0.7488i, -9.408+0.7982i, -10.545859+0.8385i, 
-11.8881+0.828i, -13.380959+0.88572i, -15.037239+1.01656i, -17.2029+1.162i, 
-19.694+1.2432i, -22.445696+1.40304i, -25.887651+1.45574i, -30.228975+1.595i, 
-35.375931+1.9397i, -41.305696+2.54628i, -48.809024+3.15948i, 
-58.765899+3.85034i, -71.971859+5.58642i, -60.387775+5.835i, 
-62.579711+6.06672i, -79.974336+6.4082i, -64.809936+6.31904i, 
-67.243299+6.58442i, -69.887979+6.88014i, -89.713584+7.50816i, 
-69.879659+7.04754i, -75.504239+7.4994i, -101.811084+9.0092i, 
-78.659036+7.84992i, -82.239375+8.2628i, -86.642439+8.74216i, 
-116.375804+11.1024i, -91.349675+9.2829i, -96.574599+9.85968i, 
-131.860624+14.352i, -101.740639+10.4838i, -107.871631+11.1696i, 
-114.179751+11.9198i, -148.127664+20.5936i, -122.875916+12.8316i, 
-129.6+13.68i, -176.127871+23.2218i, -138.850624+14.7264i, -148.4175+15.86i, 
-158.313776+16.8336i, -206.227904+30.6432i, -168.468559+18.954i, 
-181.650924+20.898i, -195.322671+23.044i, -209.479116+25.462i, 
-227.128279+28.3578i, -245.475951+31.6198i, -267.787111+35.5224i, 
-291.045776+39.9456i, -318.809775+45.287i, -351.516231+52.1512i, 
-389.680704+60.8256i, -433.8859+71.478i, -484.742775+84.643i, 
-547.5844+101.52i, -624.027084+122.7892i, -715.848204+149.8868i, 
-830.747196+185.716i, -965.762176+233.6232i, -1136.419375+300.9i, 
-1340.323975+396.27i, -1454.4384+460.112i, -1587.6711+538.936i, 
-1750.583479+634.185i, -1936.882624+750.4896i, -2129.277519+889.3422i, 
-2326.0839+1056.172i, -2575.7559+1274.724i, -2711.8179+1408.014i
))


comment(AgPalik_raw) <- c(source = "Silver in the visible, Palik", units = "microns")

AgPalik <- with(AgPalik_raw, new("dielectric", wavelength=wavelength, epsilon=epsilon, span=range(wavelength), comment=as.list(comment(AgPalik_raw))))

==> dielectric_0.2.3.tar.gz: dielectric/inst/rawdata/AuAg.r <==
require(dielectric)
AuJC_raw <- data.frame(wavelength = 1e3*c(1.93849485018727, 1.61121649885695, 1.39397382485376, 1.21631049423515, 
1.08827781063145, 0.984632304857024, 0.89254439145313, 0.821613711337649, 
0.756485795195031, 0.704907218249915, 0.659913140489282, 0.617232191104403, 
0.582458546535141, 0.548954293858341, 0.521275926100777, 0.49625468164794, 
0.471724982555076, 0.451140619679945, 0.430776633374948, 0.41354556803995, 
0.397639969269183, 0.381734370498415, 0.368141455228442, 0.354467629748529, 
0.342717321580069, 0.331721043882313, 0.320577959720891, 0.310936517323271, 
0.301125413621323, 0.292602996254682, 0.284549702779782, 0.276311069959878, 
0.269118590915369, 0.261737701291108, 0.255275041999969, 0.249123836168645, 
0.242786047772965, 0.237215430998059, 0.231462071664151, 0.226393559145958, 
0.22154226859283, 0.216516004209398, 0.212074650276897, 0.207464331792617, 
0.203383066249156, 0.199459277189687, 0.195375858916512, 0.191752195381739, 
0.187975258199977), epsilon = c(-189.042+25.3552i, -125.3505+12.5552i, -90.426461+8.18634i, 
-66.218525+5.7015i, -51.0496+3.861i, -40.2741+2.794i, -32.040669+1.92542i, 
-25.811289+1.62656i, -20.610164+1.27176i, -16.817709+1.06678i, 
-13.648209+1.03516i, -10.661884+1.37424i, -8.112669+1.66054i, 
-5.842125+2.1113i, -3.946161+2.58044i, -2.278289+3.81264i, -1.702701+4.84438i, 
-1.758996+5.28264i, -1.692204+5.6492i, -1.702164+5.71736i, -1.649404+5.73888i, 
-1.604889+5.64436i, -1.400625+5.6092i, -1.231956+5.598i, -1.310241+5.53816i, 
-1.355289+5.57368i, -1.230804+5.84584i, -1.242549+5.79258i, -1.227421+5.78034i, 
-1.306784+5.59644i, -1.332261+5.49486i, -1.366509+5.28242i, -1.346409+4.97628i, 
-1.236501+4.7223i, -1.080444+4.49008i, -0.891261+4.33846i, -0.744529+4.16328i, 
-0.616896+4.05504i, -0.551009+3.8922i, -0.4155+3.8252i, -0.346329+3.7102i, 
-0.233769+3.6062i, -0.1325+3.51i, -0.010416+3.3904i, 0.138171+3.39682i, 
0.203899+3.32766i, 0.292524+3.28568i, 0.295191+3.17592i, 0.227056+3.04128i
))

comment(AuJC_raw) <- c(source = "Gold in the visible, Johnson and Christy", 
                                units = "nanometres")

AuJC <- with(AuJC_raw, new("dielectric", wavelength=wavelength, epsilon=epsilon, span=range(wavelength), comment=as.list(comment(AuJC_raw))))

AgPalik_raw <- data.frame(wavelength=1e3*c(0.000124, 0.000155, 0.0002066, 0.000248, 0.0002755, 0.0003099, 
0.0003444, 0.0003542, 0.0004133, 0.0004959, 0.0006199, 0.0008265, 
0.00124, 0.00155, 0.001675, 0.002066, 0.00248, 0.003099, 0.003351, 
0.003542, 0.004133, 0.004428, 0.004768, 0.005166, 0.005635, 0.006199, 
0.006888, 0.007293, 0.007749, 0.008265, 0.008856, 0.009537, 0.01033, 
0.01127, 0.01181, 0.0124, 0.01305, 0.01378, 0.01459, 0.0155, 
0.01589, 0.01631, 0.01675, 0.01722, 0.01771, 0.01823, 0.01878, 
0.01937, 0.02, 0.02066, 0.02138, 0.02214, 0.02296, 0.02339, 0.02384, 
0.02431, 0.0248, 0.0253, 0.02583, 0.02638, 0.02695, 0.02818, 
0.02952, 0.03099, 0.03179, 0.03263, 0.03351, 0.03444, 0.03542, 
0.03646, 0.03757, 0.03874, 0.03999, 0.04132, 0.04275, 0.0435, 
0.04428, 0.04508, 0.04592, 0.04592, 0.04679, 0.04769, 0.04862, 
0.05061, 0.05276, 0.05391, 0.0551, 0.05636, 0.05767, 0.05904, 
0.06048, 0.06199, 0.06526, 0.06888, 0.07293, 0.07749, 0.07999, 
0.08266, 0.08551, 0.08856, 0.09184, 0.09537, 0.09919, 0.1025, 
0.1051, 0.1078, 0.1107, 0.1137, 0.117, 0.1204, 0.124, 0.1278, 
0.1348, 0.1378, 0.1409, 0.1442, 0.1476, 0.1512, 0.155, 0.159, 
0.1631, 0.1675, 0.1722, 0.1771, 0.1823, 0.1879, 0.1937, 0.1968, 
0.2, 0.2033, 0.2066, 0.2138, 0.2214, 0.2296, 0.2384, 0.248, 0.253, 
0.2583, 0.2638, 0.2695, 0.2755, 0.2818, 0.2883, 0.2952, 0.2988, 
0.3024, 0.3061, 0.31, 0.3115, 0.3139, 0.3155, 0.3179, 0.3195, 
0.322, 0.3237, 0.3263, 0.3306, 0.3324, 0.3351, 0.3397, 0.3444, 
0.3542, 0.3647, 0.3757, 0.3875, 0.4, 0.4133, 0.4275, 0.4428, 
0.4592, 0.4769, 0.4959, 0.5166, 0.5391, 0.5636, 0.5904, 0.6199, 
0.6526, 0.6888, 0.7293, 0.7749, 0.8266, 0.8856, 0.9537, 1.033, 
1.127, 1.24, 1.265, 1.291, 1.305, 1.319, 1.348, 1.378, 1.378, 
1.409, 1.442, 1.459, 1.476, 1.512, 1.55, 1.55, 1.59, 1.631, 1.653, 
1.675, 1.722, 1.771, 1.771, 1.823, 1.879, 1.907, 1.937, 2, 2.066, 
2.066, 2.138, 2.214, 2.296, 2.384, 2.48, 2.583, 2.695, 2.818, 
2.952, 3.1, 3.263, 3.444, 3.647, 3.875, 4.133, 4.428, 4.769, 
5.166, 5.636, 6.199, 6.526, 6.888, 7.293, 7.749, 8.266, 8.856, 
9.537, 9.919), 
epsilon=c(0.998000999998336+0.00000257742i, 0.999999999991473+0.00000584i, 
1.00400399993011+0.00001675344i, 1.00200099976896+0.0000304304i, 
1.00200099951159+0.0000442442i, 1.00600899872551+0.0000716142i, 
1.00600899895024+0.0000649944i, 1.00600899970416+0.0000345032i, 
1.00200099979551+0.0000286286i, 1.002000999424+0.000048048i, 
1.00200099777216+0.0000944944i, 0.998000985359+0.000241758i, 
0.996003726471+0.001043908i, 0.9940078336+0.00215352i, 0.9960019836+0.00283432i, 
0.9940017639+0.00536386i, 0.9939881151+0.00911258i, 0.9959262076+0.01760472i, 
1.0139812671+0.01657522i, 1.0019981776+0.00336336i, 0.9920106176+0.00462144i, 
0.98802871+0.0053676i, 0.9840543279+0.00617024i, 0.97810875+0.006923i, 
0.9741570975+0.0068103i, 0.9643097871+0.00740428i, 0.9564654239+0.00843036i, 
0.9467094636+0.00860132i, 0.9370048156+0.00847968i, 0.9273524351+0.00783882i, 
0.9120124684+0.0067614i, 0.8892356044+0.00690276i, 0.8574373116+0.01151944i, 
0.81330816+0.0310288i, 0.79141879+0.046458i, 0.76591676+0.0669264i, 
0.73812875+0.097293i, 0.71401124+0.1399152i, 0.703395+0.187812i, 
0.699783+0.235744i, 0.702+0.253598i, 0.702645+0.269548i, 0.700053+0.283196i, 
0.69144+0.308062i, 0.699072+0.338446i, 0.715377+0.362336i, 0.735168+0.372626i, 
0.739125+0.3717i, 0.73164+0.371782i, 0.713288+0.385866i, 0.697255+0.411432i, 
0.69156+0.451178i, 0.708149+0.48498i, 0.716475+0.4895i, 0.714145+0.490728i, 
0.706035+0.497932i, 0.697356+0.51272i, 0.693225+0.531i, 0.693063+0.548784i, 
0.69696+0.566162i, 0.698487+0.578816i, 0.696645+0.600532i, 0.682808+0.626106i, 
0.667392+0.659456i, 0.658141+0.67662i, 0.64512+0.692192i, 0.623225+0.708i, 
0.592652+0.732336i, 0.542109+0.78542i, 0.53352+0.859662i, 0.544005+0.924172i, 
0.569457+0.972576i, 0.583468+0.995376i, 0.57408+1.007342i, 0.534312+1.023766i, 
0.502737+1.042184i, 0.465504+1.06436i, 0.344745+1.048432i, 0.362496+1.1518i, 
0.618723+0.703836i, 0.607755+0.746012i, 0.589633+0.787656i, 0.574857+0.833976i, 
0.548352+0.945864i, 0.548193+1.101424i, 0.583404+1.20344i, 0.669465+1.284192i, 
0.7774+1.32225i, 0.87776+1.289472i, 0.91516+1.244298i, 0.919624+1.21329i, 
0.9053+1.203408i, 0.881991+1.23848i, 0.860552+1.305786i, 0.853416+1.42367i, 
0.904913+1.577784i, 0.967323+1.661164i, 1.0648+1.722798i, 1.17992+1.739598i, 
1.280528+1.716096i, 1.3533+1.660432i, 1.384075+1.594332i, 1.383481+1.54644i, 
1.373303+1.519896i, 1.366332+1.507424i, 1.361671+1.4898i, 1.351493+1.463676i, 
1.3248+1.4336i, 1.286625+1.4168i, 1.249408+1.412256i, 1.217457+1.409776i, 
1.190085+1.391228i, 1.094624+1.3002i, 1.015497+1.268496i, 0.919575+1.252112i, 
0.813768+1.246826i, 0.692924+1.25904i, 0.55964+1.296858i, 0.427008+1.358344i, 
0.2907+1.4476i, 0.182001+1.55584i, 0.080432+1.669824i, -0.017037+1.791684i, 
-0.111891+1.92506i, -0.205939+2.07366i, -0.286875+2.2487i, -0.335616+2.42608i, 
-0.365796+2.53616i, -0.388416+2.65856i, -0.381996+2.76696i, -0.347275+2.8575i, 
-0.288171+3.02634i, -0.230736+3.1408i, -0.183456+3.24356i, -0.168675+3.3649i, 
-0.137696+3.5046i, -0.0801+3.564i, -0.018851+3.6261i, 0.059884+3.7044i, 
0.202316+3.73464i, 0.360381+3.77542i, 0.590976+3.71952i, 0.839904+3.57476i, 
1.140961+3.28104i, 1.33242+3.019648i, 1.460092+2.638944i, 1.463868+2.193824i, 
1.33172+1.711962i, 1.20912+1.460312i, 1.028601+1.24092i, 0.82574+1.073232i, 
0.614608+0.939456i, 0.387549+0.85738i, 0.182039+0.80004i, 0.008575+0.750288i, 
-0.162893+0.697476i, -0.523328+0.603246i, -0.710563+0.579084i, 
-0.88576+0.579768i, -1.187319+0.58016i, -1.480956+0.59024i, -2.029919+0.60192i, 
-2.557504+0.59892i, -2.7489+0.668i, -3.239236+0.69504i, -3.772571+0.6747i, 
-4.422171+0.73006i, -5.082+0.7232i, -5.735351+0.7536i, -6.532864+0.73728i, 
-7.380976+0.71808i, -8.2775+0.7488i, -9.408+0.7982i, -10.545859+0.8385i, 
-11.8881+0.828i, -13.380959+0.88572i, -15.037239+1.01656i, -17.2029+1.162i, 
-19.694+1.2432i, -22.445696+1.40304i, -25.887651+1.45574i, -30.228975+1.595i, 
-35.375931+1.9397i, -41.305696+2.54628i, -48.809024+3.15948i, 
-58.765899+3.85034i, -71.971859+5.58642i, -60.387775+5.835i, 
-62.579711+6.06672i, -79.974336+6.4082i, -64.809936+6.31904i, 
-67.243299+6.58442i, -69.887979+6.88014i, -89.713584+7.50816i, 
-69.879659+7.04754i, -75.504239+7.4994i, -101.811084+9.0092i, 
-78.659036+7.84992i, -82.239375+8.2628i, -86.642439+8.74216i, 
-116.375804+11.1024i, -91.349675+9.2829i, -96.574599+9.85968i, 
-131.860624+14.352i, -101.740639+10.4838i, -107.871631+11.1696i, 
-114.179751+11.9198i, -148.127664+20.5936i, -122.875916+12.8316i, 
-129.6+13.68i, -176.127871+23.2218i, -138.850624+14.7264i, -148.4175+15.86i, 
-158.313776+16.8336i, -206.227904+30.6432i, -168.468559+18.954i, 
-181.650924+20.898i, -195.322671+23.044i, -209.479116+25.462i, 
-227.128279+28.3578i, -245.475951+31.6198i, -267.787111+35.5224i, 
-291.045776+39.9456i, -318.809775+45.287i, -351.516231+52.1512i, 
-389.680704+60.8256i, -433.8859+71.478i, -484.742775+84.643i, 
-547.5844+101.52i, -624.027084+122.7892i, -715.848204+149.8868i, 
-830.747196+185.716i, -965.762176+233.6232i, -1136.419375+300.9i, 
-1340.323975+396.27i, -1454.4384+460.112i, -1587.6711+538.936i, 
-1750.583479+634.185i, -1936.882624+750.4896i, -2129.277519+889.3422i, 
-2326.0839+1056.172i, -2575.7559+1274.724i, -2711.8179+1408.014i
))


comment(AgPalik_raw) <- c(source = "Silver in the visible, Palik", units = "nanometres")

AgPalik <- with(AgPalik_raw, new("dielectric", wavelength=wavelength, epsilon=epsilon, span=range(wavelength), comment=as.list(comment(AgPalik_raw))))

save(AuJC, file="AuJC.rda")
save(AgPalik , file="AgPalik.rda")
